supercell — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# supercell

poscar_supercell.supercell(size: ndarray) → Poscar

  Creates a supercell of the given size. The content of the original Poscar is overwritten

  size = [[b1x, b1y, b1z],

    [b2x, b2y, b2z], [b3x, b3y, b3z]]

  Parameters:

    size (ndarray) – (3x3) array of integers with the supercell vectors in term of the original lattice vectors. The order is [[b1x, b1y, b1z], [b2x, …] …]

  Returns:

    Poscar – A Poscar object with the desired supercell. It is the same instance stored in this class. Note, the creation of poscar_supercell makes a deep copy of the Poscar instance provided